"""Utility functions."""

from __future__ import absolute_import, print_function

from io import StringIO
from nbformat.v3 import nbpy
import nbformat as nbf

from .reader import py_string_to_ipy_string, py_file_to_ipy_string


__all__ = ['py_string_to_notebook', 'py_file_to_notebook',
           'write_notebook_to_string', 'python_to_notebook']



def py_string_to_notebook(str, nbver=None):
    """Convert a string representation of a regular Python script into
    a notebook object.
    """

    ipy = py_string_to_ipy_string(str)
    # Read using v3 of nbformat
    with StringIO(ipy) as fin:
        nb = nbpy.read(fin)

    # Convert to specific notebook version if specified
    if nbver is not None:
        nb = nbf.convert(nb, nbver)

    return nb


def py_file_to_notebook(filename, nbver=None):
    """Convert a Python file into a notebook object."""

    ipy = py_file_to_ipy_string(filename)
    # Read using v3 of nbformat
    with StringIO(ipy) as fin:
        nb = nbpy.read(fin)

    # Convert to specific notebook version if specified
    if nbver is not None:
        nb = nbf.convert(nb, nbver)

    return nb


def write_notebook(nb, filename, nbver=nbf.current_nbformat):
    """Write a notebook object to a file. Use the most recent version of
    nbformat by default."""

    with open(filename, 'w') as fout:
        nbf.write(nb, fout, version=nbver)


def write_notebook_to_string(nb, nbver=nbf.current_nbformat):
    """Write a notebook object to a string.  Use the most recent
    version of nbformat by default.
    """

    with StringIO('') as fout:
        nbf.write(nb, fout, version=nbver)
        str = fout.getvalue()
    return str


def python_to_notebook(input_filename, output_filename):
    """Convert the given python source file into a properly formatted
    notebook.
    """

    nb = py_file_to_notebook(input_filename)
    write_notebook(nb, output_filename)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup
from ast import parse


name = 'py2jn'
# See http://stackoverflow.com/questions/2058802
with open('py2jn/__init__.py') as f:
    version = parse(next(filter(
        lambda line: line.startswith('__version__'),
        f))).body[0].value.s

packages = [name]

longdesc = \
"""
py2jn is a small utility for converting Python scripts into Jupyter
Notebooks and convert module-level multiline (triple quote) string
literals into markdown cells.
"""

setup(
    name             = name,
    version          = version,
    packages         = packages,
    description      = 'py2jn: convert Python script to Jupyter Notebook',
    long_description = longdesc,
    keywords         = ['Jupyter Notebook'],
    platforms        = 'Any',
    license          = 'BSD',
    url              = 'https://github.com/bwohlberg/py2jn',
    author           = 'Siu Kwan Lam',
    author_email     = None,
    maintainer       = 'Brendt Wohlberg',
    maintainer_email = 'brendt@ieee.org',
    setup_requires   = [],
    tests_require    = ['pytest', 'pytest-runner'],
    install_requires = ['nbformat'],
    extras_require   = {
        'tests': ['pytest', 'pytest-runner']},
    classifiers = [
    'Development Status :: 4 - Beta',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: BSD License',
    'Operating System :: OS Independent',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3',
    'Topic :: Utilities',
    ],
    zip_safe = True
)



"""
# Hello

Demonstrate:
* conversion of regular python script into _Jupyter notebook_
* support **Markdown**
* this is a list
"""

from __future__ import absolute_import, print_function, division

"""
## Hello

This is a *hello world* function.

"""


def hello():
    """
    This is a docstring
    """
    print("hello")


"""
## Another Cell 1
"""


def main():
    hello()


"""
### Run this
"""

if __name__ == '__main__':
    def what():
        main()
    print(what())


"""
## Another Cell 2
"""
